@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.8';
+our $VERSION = '0.9';
 
 use warnings;
 use strict;
@@ -42,7 +42,7 @@ sub populate {
     elsif ($data_ref eq 'HASH') {
         for my $vertex (keys %$data) {
             for my $entry ( keys %{ $data->{$vertex} } ) {
-                if ( $entry !~ /\A\d+\z/ ) {
+                if ( $entry eq 'label' ) {
                     my $label = delete $data->{$vertex}{$entry};
                     $self->set_vertex_attribute($vertex, $entry, $label);
                 }
@@ -212,7 +212,9 @@ sub dump {
     my $attr = shift || 'weight';
 
     for my $vertex ( sort { $a <=> $b } $self->vertices ) {
-        printf "vertex: %s %s=%.2f\n",
+        my $label = $self->get_vertex_attribute($vertex, 'label');
+        printf "%svertex: %s %s=%.2f\n",
+            ( $label ? "$label " : '' ),
             $vertex,
             $attr,
             $self->get_cost( $vertex, $attr );
@@ -239,7 +241,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.8
+version 0.9
 
 =head1 SYNOPSIS
 
@@ -265,10 +267,10 @@ version 0.8
  $gw = Graph::Weighted->new;
  $gw->populate(
     {
-        0 => { label => 'A', foo => 'a', 1=>0.4, 3=>0.6 },
-        1 => { label => 'B', foo => 'b', 0=>0.3, 2=>0.7 },
-        2 => { label => 'C', foo => 'c', 0=>0.5, 2=>0.5 },
-        3 => { label => 'D', foo => 'd', 0=>0.2, 1=>0.8 },
+        0 => { label => 'A', 1=>0.4, 3=>0.6 },
+        1 => { label => 'B', 0=>0.3, 2=>0.7 },
+        2 => { label => 'C', 0=>0.5, 2=>0.5 },
+        3 => { label => 'D', 0=>0.2, 1=>0.8 },
     },
     $attr
  );
@@ -302,7 +304,7 @@ Please see L<Graph/Constructors> for the possible constructor arguments.
 Populate a graph with weighted nodes.
 
 The data can be an arrayref of numeric vectors, a C<Math::Matrix> object, a
-C<Math::MatrixReal> object, or a hashref of numeric edge values.
+C<Math::MatrixReal> object, or a hashref of edge values.
 
 Data given as a hash reference may also contain multiple node labels.  Also, the
 keys need not be numeric, just unique.
